task Manta {
  
  File ref_dir
	File fasta
  File regions
  File tumor_bam
  File tumor_bam_index
  File? normal_bam
  File? normal_bam_index
	String sample
	String docker
	String cluster_config
	String disk_size
  
	command <<<
    set -o pipefail
    set -e
		nt=$(nproc)
    
    MANTA_INSTALL_PATH="/opt/manta-1.6.0.centos6_x86_64"
    MANTA_ANALYSIS_PATH="/cromwell_root/tmp"
		mkdir -p $MANTA_ANALYSIS_PATH
    
    cp ${regions} my_baits.bed
    bgzip -c my_baits.bed > my_baits.bed.gz
    tabix -p bed my_baits.bed.gz
    # input files
    if [ ${normal_bam} ]; then
      INPUT="--normalBam ${normal_bam} --tumorBam ${tumor_bam}"
    else
      INPUT="--tumorBam ${tumor_bam}"
    fi
    # configManta
    $MANTA_INSTALL_PATH/bin/configManta.py \
    $INPUT \
    --callRegions my_baits.bed.gz --exome \
    --referenceFasta ${ref_dir}/${fasta} \
    --runDir $MANTA_ANALYSIS_PATH
    # runWorkflow
    $MANTA_ANALYSIS_PATH/runWorkflow.py -j $nt
    # results
    if [ ${normal_bam} ]; then
      cp $MANTA_ANALYSIS_PATH/results/variants/somaticSV.vcf.gz ${sample}.Manta.somaticSV.vcf.gz
      cp $MANTA_ANALYSIS_PATH/results/variants/diploidSV.vcf.gz ${sample}.Manta.germlineSV.vcf.gz
    else
      cp $MANTA_ANALYSIS_PATH/results/variants/tumorSV.vcf.gz ${sample}.Manta.somaticSV.vcf.gz
    fi
	>>>
  
	runtime {
		docker:docker
    cluster: cluster_config
    systemDisk: "cloud_ssd 40"
    dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
	}
  
	output {
		File somatic_vcf = "${sample}.Manta.somaticSV.vcf.gz"
		File? germline_vcf = "${sample}.Manta.germlineSV.vcf.gz"
	}
}